import scrapy
import re
import logging
from crawl.comm.football import FTResult
from crawl.spiders.util import getNoneStr

class FootballSpider(scrapy.Spider):
  name = "football-result"

  # 所有比赛
  _matchesMap = {}

  def start_requests(self):
    url = 'https://info.sporttery.cn/football/match_result.php'
    yield scrapy.Request(url, self.parseResult, 'GET')

  def parseResult(self, response):
    # 处理比赛结果
    cssOfMatch = '.all-wrap > .match_list .m-tab tr'
    matches = response.css(cssOfMatch)
    if matches is None: return
    for matchNode in matches:
      tdNodeList = matchNode.css('td')
      if tdNodeList is None or len(tdNodeList) < 10:
        continue

      matchTime = getNoneStr(tdNodeList[0].css('::text').get())
      matchWeek = getNoneStr(tdNodeList[1].css('::text').get())
      league = getNoneStr(tdNodeList[2].css('::text').get())
      leagueFullName = getNoneStr(tdNodeList[2].attrib.get('title'))  # 联赛全称
      leagueName = '|'.join((league, leagueFullName))
      homeTeam = self.trimBrackets(tdNodeList[3].css('.zhu::text').get()) # 主队
      awayTeam = self.trimBrackets(tdNodeList[3].css('.ke::text').get()) # 客队
      half = getNoneStr(tdNodeList[4].css('span::text').get())
      whole = getNoneStr(tdNodeList[5].css('span::text').get())
      status = getNoneStr(tdNodeList[9].css('::text').get())

      if status == '进行中':
        continue

      ftResult = FTResult(
        matchTime,
        matchWeek,
        leagueName,
        homeTeam,
        awayTeam,
        '', # 不需要单固
        half,
        whole,
        status,
        ''
      )

      matchLink = getNoneStr(tdNodeList[3].css('a').attrib.get('href'))
      matchId = re.sub(r'^.*fb_match_info.php\?m=', '', matchLink)

      # 加入到临时字典里
      self._matchesMap[matchId] = ftResult


      if status == '已完成':
        link = "https://i.sporttery.cn/api/fb_match_info/get_pool_rs?mid=" + matchId
        yield scrapy.Request(link, self.parsePrice, 'GET')
      else:
        logging.info("采集到数据 --> %s" % ftResult.toString())
        ftResult.persist()


    # 是否存在下一页
    pgNodes = response.css('.m-page .u-pg2')
    if pgNodes is None or len(pgNodes) < 1: return

    # 总页数
    total = pgNodes[-1].css('a::text').get()
    if total is None or total == '':
      total = 0

    # 当前页数
    current = re.sub(r'^.*match_result.php[?page=]*', '', response.url)
    if current is None or current == '':
      current = 1

    if int(current) >= int(total): return

    # 下一页
    nextPG = int(current) + 1
    url = 'https://info.sporttery.cn/football/match_result.php?page=' + str(nextPG)
    yield scrapy.Request(url, self.parseResult, 'GET')


  def trimBrackets(self, str):
    if str is None: return ''

    return re.sub(r'\(.*\)', '', str)

  def parsePrice(self, response):
    logging.info("采集数据源 ---> %s" % response.url)
    
    data = response.json()
    res = data.get('result').get('pool_rs')

    playRes = []

    # 胜平负
    try:
      playRes.append(res['had']['prs_name'])
    except:
      playRes.append('')
    
    # 让球胜平负
    try:
      playRes.append(res['hhad']['prs_name'])
    except:
      playRes.append('')
    
    # 比分
    try:
      playRes.append(res['crs']['prs_name'])
    except:
      playRes.append('')
    
    # 总进球
    try:
      playRes.append(res['ttg']['prs_name'])
    except:
      playRes.append('')
    
    # 半全场
    try:
      playRes.append(res['hafu']['prs_name'])
    except:
      playRes.append('')
    
    matchId = re.sub(r'^.*get_pool_rs\?mid=', '', response.url)
    ftResult = self._matchesMap[matchId]
    ftResult.playRes = '|'.join(playRes)

    #
    logging.info("采集到数据 --> %s" % ftResult.toString())

    # 入库
    ftResult.persist()
