import scrapy

from crawl.comm.lottery import LotteryResult, LotteryResultDetail


class LotterySpider(scrapy.Spider):
  name = "lottery"

  def start_requests(self):
    # 大乐透
    url = "https://webapi.sporttery.cn/gateway/lottery/getHistoryPageListV1.qry?gameNo=85&provinceId=0&pageSize=1&isVerify=1&pageNo=1"
    yield scrapy.Request(url, self.parseLottery, 'GET')

    # 排列三, 排列五
    url = "https://webapi.sporttery.cn/gateway/lottery/getHistoryPageListV1.qry?gameNo=35&provinceId=0&pageSize=1&isVerify=1&pageNo=1"
    yield scrapy.Request(url, self.parseP3, 'GET')
    
    url = "https://webapi.sporttery.cn/gateway/lottery/getHistoryPageListV1.qry?gameNo=350133&provinceId=0&pageSize=1&isVerify=1&pageNo=1"
    yield scrapy.Request(url, self.parseP5, 'GET')

    # 双色球
    url = "https://api.xinti.com/chart/QueryPrizeDetailInfo"
    body = '''
      {
        "ClientSource": 3,
        "Param":{
          "GameCode": "SSQ"
        }
      }
    '''
    yield scrapy.Request(url, self.parseDraw, 'POST', None, body)

  # 大乐透
  def parseLottery(self, response):
    data = response.json()
    try:
      data = data['value']['list'][0]
    except:
      return

    # 大乐透
    typ = 'lottery'
    result = LotteryResult(
      typ,
      data['lotteryDrawNum'],
      data['lotteryDrawTime'],
      '|'.join(data['lotteryDrawResult'].split(' '))
    )

    details = []
    # 一等奖 + 追加
    it = data['prizeLevelList'][0]
    xIt = data['prizeLevelList'][1]
    detail = LotteryResultDetail(it.get('prizeLevel'), it.get('stakeCount'), it.get('stakeAmount'))
    detail.add(xIt.get('stakeCount'), xIt.get('stakeAmount'))
    details.append(detail)
    # 二等奖 + 追加
    it = data['prizeLevelList'][2]
    xIt = data['prizeLevelList'][3]
    detail = LotteryResultDetail(it.get('prizeLevel'), it.get('stakeCount'), it.get('stakeAmount'))
    detail.add(xIt.get('stakeCount'), xIt.get('stakeAmount'))
    details.append(detail)

    for i, item in enumerate(data['prizeLevelList']):
      if i < 4:
        continue

      detail = LotteryResultDetail(item.get('prizeLevel'), item.get('stakeCount'), item.get('stakeAmount'))
      detail.add('', '')
      details.append(detail)
    result.setDetails(details)

    result.persist()

  def parseP3(self, response):
    self.parsePermutation(response, 'p3')

  def parseP5(self, response):
    self.parsePermutation(response, 'p5')

  # 排列三/五
  def parsePermutation(self, response, typ):
    data = response.json()
    try:
      data = data['value']['list'][0]
    except:
      return

    # 排列三/五
    result = LotteryResult(
      typ,
      data['lotteryDrawNum'],
      data['lotteryDrawTime'],
      '|'.join(data['lotteryDrawResult'].split(' '))
    )

    details = []
    for i, item in enumerate(data['prizeLevelList']):
      detail = LotteryResultDetail(item.get('prizeLevel'), item.get('stakeCount'), item.get('stakeAmount'))
      details.append(detail)

    result.setDetails(details)
    result.persist()

  # 福彩 - 双色球
  def parseDraw(self, response):
    data = response.json()
    data = data['Value']

    typ = 'double-color'
    result = LotteryResult(
      typ,
      data['PreIssuseInfo']['IssuseNumber'].replace('-', ''),
      data['PreIssuseInfo']['AwardTime'],
      data['PreIssuseInfo']['WinNumber'].replace(',', '|')
    )

    details = []
    for item in data['BonusPoolList']:
      level = item.get('PrizeName')

      detail = LotteryResultDetail(level, str(item.get('WinCount')), str(item.get('SingleWinBonus')))
      details.append(detail)

    result.setDetails(details)
    result.persist()
